{This unit is based on the PARDRV.H file and is meant for the parallel driver}
{$MINENUMSIZE 2}

unit USBConst;

interface

uses
  Windows,
  SysUtils;


const
  ENV_DOS    = 0;
  ENV_WIN    = 1;
  ENV_WIN32  = 2;
  ENV_WIN32S = 3;
  ENV_WINNT  = 4;
  TARGET     = ENV_WIN;

  CS_PULSE_IN_ACTIVE = $8000;
  CS_WAITING_FOR_TRIGGER = $8000;


(* General Purpose Flags *)
{set in ccd parameter of EndExposure command to skip synchronization delay.
 Use this to increase the rep rate when taking darks to later be subtracted
 from SC_LEAVE_SHUTTER exposures such as when tracking and imaging}
  END_SKIP_DELAY  = $8000;

{set in exposureTime to wait for trigger in pulse}
  EXP_WAIT_FOR_TRIGGER_IN  = $80000000;

{set in exposureTime to send trigger out Y-}
  EXP_SEND_TRIGGER_OUT = $40000000;

{mask with exposure time to remove flags}
  EXP_TIME_MASK = $00FFFFFF;

{Minimum exposure is 11/100ths second}
  MIN_ST7_EXPOSURE = 11;

{command is idle}
  TCES_IDLE_STATUS = 0;

{command is in progress}
  TCES_IN_PROGRESS = 1;

{feature is disabled}
  TCES_DISABLED = 0;

{feature is enabled}
  TCES_ENABLED = 1;

{this indicates an extended error occured and the TCEC_GET_EXTENDED_ERROR
 command should be called for further info}
  TCES_EXTENDED_ERROR = 99;

type
  TImgFile = File;

  TExposureMode = (emDarkLightNew, emDarkLightKeep, emDarkOnly, emLightOnly);
  TLoopMode = (lmOneshot, lmPause, lmContinuous, lmFixed);

  TCurrentCameraInfo = packed record
    ABG         : Boolean;
    CameraType  : Word;
    CameraMode  : Word;
    ExposureMode: TExposureMode;
    CameraName  : string[64];
    ImageWidth  : Word;
    ImageHeight : Word;
    CCDType     : Word;
    SetPointTemp: Double;
    PixcelFilter: Word;
  end;

  TCurrentExposureInfo = packed record
    FocusMode   : Boolean;
    Exposure    : longint;
    LoopMode    : TLoopMode;
    LoopCount   : Word;
    LoopDelay   : Word;
  end;

(*
  Enumerated Constants
  --------------------
  Note that the various constants are declared here as enums for ease of
  declaration but in the structures that use the enums unsigned shorts
  are used to force the various 16 and 32 bit compilers to use 16 bits.


  Supported Camera Commands
  -------------------------
  These are the commands supported by the driver. They are prefixed by
  CC_ to designate them as camera commands and avoid conflicts with other
  enums.

  Some of the commands are marked as SBIG use only and have been
  included to enhance testability of the driver for SBIG.
*)

  TPAR_COMMAND = (CC_ZERO,                             {0}
                  CC_START_EXPOSURE,
                  CC_END_EXPOSURE,
                  CC_READOUT_LINE,
                  CC_DUMP_LINES,
                  CC_SET_TEMPERATURE_REGULATION,
                  CC_QUERY_TEMPERATURE_STATUS,
                  CC_ACTIVATE_RELAY,
                  CC_PULSE_OUT,
                  CC_ESTABLISH_LINK,
                  CC_GET_DRIVER_INFO,                  {10}
                  CC_GET_CCD_INFO,
                  CC_QUERY_COMMAND_STATUS,
                  CC_MISCELLANEOUS_CONTROL,
                  CC_READ_SUBTRACT_LINE,
                  CC_UPDATE_CLOCK,
                  CC_READ_OFFSET,
                  CC_OPEN_DRIVER,
                  CC_CLOSE_DRIVER,
                  CC_TX_SERIAL_BYTES,
                  CC_GET_SERIAL_STATUS,                {20}
                  CC_AO_TIP_TILT,
                  CC_AO_SET_FOCUS,
                  CC_AO_DELAY,
{SBIG ONLY}

                  CC_SEND_BLOCK,
                  CC_SEND_BYTE,
                  CC_GET_BYTE,
                  CC_SEND_AD,
                  CC_GET_AD,
                  CC_CLOCK_AD,
                  CC_LAST_COMMAND);

(*
	Return Error Codes

	These are the error codes returned by the driver function.
        They are prefixed with CE_ to designate them as camera errors.
*)

  TPAR_ERROR = (CE_NO_ERROR,                 {0}
                CE_CAMERA_NOT_FOUND,
                CE_EXPOSURE_IN_PROGRESS,
                CE_NO_EXPOSURE_IN_PROGRESS,
                CE_UNKNOWN_COMMAND,
                CE_BAD_CAMERA_COMMAND,       {5}
                CE_BAD_PARAMETER,
                CE_TX_TIMEOUT,
                CE_RX_TIMEOUT,
                CE_NAK_RECEIVED,
                CE_CAN_RECEIVED,             {10}
                CE_UNKNOWN_RESPONSE,
                CE_BAD_LENGTH,
                CE_AD_TIMEOUT,
                CE_KBD_ESC,
                CE_CHECKSUM_ERROR,           {15}
                CE_EEPROM_ERROR,
                CE_SHUTTER_ERROR,
                CE_UNKNOWN_CAMERA,
                CE_DRIVER_NOT_FOUND,
                CE_DRIVER_NOT_OPEN,          {20}
                CE_DRIVER_NOT_CLOSED,
                CE_SHARE_ERROR,
                CE_TCE_NOT_FOUND,
                CE_AO_ERROR,
                CE_NEXT_ERROR);              {25}

(*
	Camera Command State Codes

	These are the return status codes for the Query Command Status command.
        They are prefixed with CS_ to designate them as camera status.
*)

  TPAR_COMMAND_STATUS = (CS_IDLE,
                        CS_IN_PROGRESS,
                        CS_INTEGRATING,
                        CS_INTEGRATION_COMPLETE);


{Passed to Start Exposure Command}
  TABG_STATE7 = (ABG_LOW7, ABG_CLK_LOW7, ABG_CLK_MED7, ABG_CLK_HI7);

{General purpose type}
  LOGICAL = Word;

{Used with Get Driver Info command}
 TDRIVER_REQUEST = (DRIVER_STD);

{Used with Imaging commands to specify CCD}
  TCCD_REQUEST = (CCD_IMAGING, CCD_TRACKING);

{Used with Get CCD Info Command}
  TCCD_INFO_REQUEST = (CCD_INFO_IMAGING, CCD_INFO_TRACKING,
                       CCD_INFO_EXTENDED, CCD_INFO_EXTENDED_5C);

  TIMAGING_ABG = (ABG_NOT_PRESENT, ABG_PRESENT);

{Used with Establish Link Command}
  TPORT = (BASE_ADDR, PORT0, PORT1, PORT2);

  TPORT_RATE = (BR_AUTO, BR_9600, BR_19K, BR_38K, BR_57K, BR_115K);

{Returned by Establish Link and Get CCD Info commands}
  TCAMERA_TYPE = (STZERO, STONE, STTWO, STTHREE, ST7_CAMERA,
                  ST8_CAMERA, ST5C_CAMERA, TCE_CONTROLLER,
                  ST237_CAMERA, STK_CAMERA, ST9_CAMERA);

{Used with Start Exposure and Miscellaneous Control Commands}
  TSHUTTER_COMMAND = (SC_LEAVE_SHUTTER, SC_OPEN_SHUTTER,
                      SC_CLOSE_SHUTTER, SC_INITIALIZE_SHUTTER);

{Used with Start Exposure and Miscellaneous Control Commands}
  TSHUTTER_STATE7 = (SS_OPEN, SS_CLOSED, SS_OPENING, SS_CLOSING);

{Used with Enable Temperature Regulation}
  TTEMPERATURE_REGULATION = (REGULATION_OFF,
                             REGULATION_ON,
                             REGULATION_OVERRIDE);

{Used with the Miscellaneous Control Command}
  TLED_STATE = (LED_OFF, LED_ON, LED_BLINK_LOW, LED_BLINK_HIGH);

{Used with the Miscellaneous Control Command}
  TFILTER_COMMAND = (FILTER_LEAVE, FILTER_SET_1, FILTER_SET_2, FILTER_SET_3,
	             FILTER_SET_4, FILTER_SET_5, FILTER_STOP, FILTER_INIT);

{Used with the Miscellaneous Control Command}
  TFILTER_STATE = (FS_MOVING, FS_AT_1, FS_AT_2, FS_AT_3,
                   FS_AT_4, FS_AT_5, FS_UNKNOWN);

{Used with the GetCCDInfo3 Command}
  TAD_SIZE = (AD_UNKNOWN, AD_12_BITS, AD_16_BITS);

{Used with the GetCCDInfo3 Command}
  TFILTER_TYPE = (FW_UNKNOWN, FW_EXTERNAL, FW_VANE, FW_FILTER_WHEEL);

{Used with the AO Set Focus Command}
  TAO_FOCUS_COMMAND = (AOF_HARD_CENTER, AOF_SOFT_CENTER,
                       AOF_STEP_IN, AOF_STEP_OUT);


  TStartExposureParams = packed record
    CCD           : Word;
    ExposureTime  : longint;
    ABGState      : Word;
    OpenShutter   : Word;
  end;

  TEndExposureParams = packed record
    CCD : Word;
  end;

  TReadoutLineParams = packed record
    CCD          : Word;
    ReadoutMode  : Word;
    PixelStart   : Word;
    PixelLength  : Word;
  end;

  TEndReadoutParams = packed record
    CCD : Word;
  end;

  TDumpLinesParams = packed record
    CCD          : Word;
    ReadoutMode  : Word;
    LineLength   : Word;
  end;

  TSetTemperatureRegulationParams = packed record
    Regulation   : Word;
    CCDSetpoint  : Word;
  end;

  TQueryTemperatureStatusResults = packed record
    Enabled           : LOGICAL;
    CCDSetpoint       : Word;
    Power             : Word;
    CCDThermistor     : Word;
    AmbientThermistor : Word;
  end;

  TActivateRelayParams = packed record
    tXPlus   : Word;
    tXMinus  : Word;
    tYPlus   : Word;
    tYMinus  : Word;
  end;

  TPulseOutParams = packed record
    NumberPulses  : Word;
    PulseWidth    : Word;
    PulsePeriod   : Word;
  end;

  TTXSerialBytesParams = packed record
    DataLength  : Word;
    Data        : array[0..255] of char;
  end;

  TTXSerialBytesResults = packed record
    BytesSent  : Word;
  end;

  TGetSerialStatusResults = packed record
    ClearToCOM  : LOGICAL;
  end;

  TEstablishLinkParams = packed record
    Port         : Word;
    BaseAddress  : Word;
  end;

  TEstablishLinkResults = packed record
    CameraType  : Word;
  end;

  TGetDriverInfoParams = packed record
    Request  : Word;
  end;

  TGetDriverInfoResults0 = packed record
    Version    : Word;
    Name       : array[0..63] of char;
    MaxRequest : Word;
  end;

  TGetCCDInfoParams = packed record
    Request  : Word;
  end;

  READOUT_INFO = Smallint;

  TReadoutInfo = packed record
    Mode        : Word;
    Width       : Word;
    Height      : Word;
    Gain        : Word;
    PixelWidth  : longint;
    PixelHeight : longint;
  end;

  TGetCCDInfoResults0 = packed record
    FirmwareVersion   : Word;
    CameraType        : Word;
    Name              : array[0..63] of char;
    ReadoutModes      : Word;
    ReadoutInfo       : array[0..19] of TReadoutInfo;
  end;

  TGetCCDInfoResults2 = packed record
    BadColumns   : Word;
    Columns      : array[0..3] of Word;
    ImagingABG   : Word;
    SerialNumber : array[0..9] of char;
  end;

  TGetCCDInfoResults3 = packed record
    AdSize     : Word;
    FilterType : Word;
  end;

  TQueryCommandStatusParams = packed record
    Command  : Word;
  end;

  TQueryCommandStatusResults = packed record
    Status  : Word;
  end;

  TMiscellaneousControlParams = packed record
    FanEnable      : LOGICAL;
    ShutterCommand : Word;
    LEDState       : Word;
    FilterCommand  : Word;
  end;

  TReadOffsetParams = packed record
    CCD   : Word;
  end;

  TReadOffsetResults = packed record
    Offset  : Word;
  end;

  TAOTipTiltParams = packed record
    xDeflection  : Word;
    yDeflection  : Word;
  end;

  TAOSetFocusParams = packed record
    FocusCommand  : Word;
  end;

  TAODelayParams = packed record
    Delay   : longint;
  end;

  TSendBlockParams = packed record
    Port     : Word;
    Length   : Word;
    Source   : PChar;
  end;

  TSendByteParams = packed record
    Port   : Word;
    Data   : Word;
  end;

  TClockADParams = packed record
    CCD          : Word;
    ReadoutMode  : Word;
    PixelStart   : Word;
    PixelLength  : Word;
  end;


(* These are the various commands the TCE supports. They are all prefaced
   with TCEC_ so commands with the same name will not conflict with the
   Universal CPU or ST-7/8 commands.
*)

  TTCE_COMMAND = (TCEC_NO_COMMAND,                    {0}
                  TCEC_GET_ENCODERS,
                  TCEC_SYNC_ENCODERS,
                  TCEC_RESET_ENCODERS,
                  TCEC_GET_EXTENDED_ERROR,
                  TCEC_GET_ACTIVITY_STATUS,
                  TCEC_MOVE,
                  TCEC_ABORT,
                  TCEC_GOTO,
                  TCEC_COMMUTATE,
                  TCEC_INITIALIZE,                    {10}
                  TCEC_PARK,
                  TCEC_ENABLE_COMMUTATION,
                  TCEC_ACTIVATE_FOCUS,
                  TCEC_ENABLE_PEC,
                  TCEC_TRAIN_PEC,
                  TCEC_OUTPUT_DEW,
                  TCEC_TX_TO_EXP,
                  TCEC_ENABLE_LIMIT,
                  TCEC_SET_EXP_CONTROL,
                  TCEC_GET_EXP_STATUS,                {20}
                  TCEC_GET_RESULT_BUF,
                  TCEC_LIMIT_STATUS,
                  TCEC_WRITE_BLOCK,
                  TCEC_READ_BLOCK,
                  TCEC_GET_ROM_VERSION,
                  TCEC_SET_COM_BAUD,
                  TCEC_SET_MOTION_CONTROL,
                  TCEC_GET_MOTION_CONTROL,
                  TCEC_READ_THERMISTOR,
                  TCEC_GET_MOTION_STATE,              {30}
                  TCEC_SET_SIDEREAL_CLOCK,
                  TCEC_GET_SIDEREAL_CLOCK,
                  TCEC_LOOPBACK_EXP_TEST,
                  TCEC_GET_KEY,
                  TCEC_GET_KEYS,
                  TCEC_GET_EEPROM_DATA,
                  TCEC_GET_TCE_INFO,
                  TCEC_SET_EEPROM_DATA,
                  TCEC_HOLD39,
                  TCEC_HOLD40,                        {40}
                  TCEC_HOLD41,
                  TCEC_HOLD42,
                  TCEC_HOLD43,
                  TCEC_HOLD44,
                  TCEC_HOLD45,
                  TCEC_HOLD46,
                  TCEC_HOLD47,
                  TCEC_READ_EE_BLOCK,                 {48}
                  TCEC_WRITE_EE_BLOCK,
                  TCEC_MICRO_OUT,                     {50}
                  TCEC_READ_R0,
                  TCEC_WRITE_R0,
                  TCEC_READ_GA,
                  TCEC_WRITE_GA,
                  TCEC_GET_EBS,
                  TCEC_HOLD56,
                  TCEC_HOLD57,
                  TCEC_HOLD58,
                  TCEC_HOLD59,
                  TCEC_HOLD60,                        {60}
                  TCEC_HOLD61,
                  TCEC_HOLD62,
                  TCEC_HOLD63,
                  TCEC_SEND_BLOCK,                    {64}
                  TCEC_HOLD65,
                  TCEC_HOLD66,
                  TCEC_HOLD67,
                  TCEC_HOLD68,
                  TCEC_HOLD69,
                  TCEC_HOLD70,                        {70}
                  TCEC_HOLD71,
                  TCEC_HOLD72,
                  TCEC_HOLD73,
                  TCEC_HOLD74,
                  TCEC_HOLD75,
                  TCEC_HOLD76,
                  TCEC_HOLD77,
                  TCEC_HOLD78,
                  TCEC_HOLD79,
                  TCEC_OPEN_DRIVER,                   {80}
                  TCEC_CLOSE_DRIVER,
                  TCEC_GET_DRIVER_INFO,
                  TCEC_ESTABLISH_LINK,
                  TCEC_HARDWARE_RESET);

{Move and Goto speeds - Use with the TCEC_MOVE and TCEC_GOTO commands}
  TMOVE_SPEED = (MOVE_STOP,
                 MOVE_BASE,
                 MOVE_LEAVE,
                 MOVE_0R5X,
                 MOVE_1X,
                 MOVE_2X,
                 MOVE_4X,
                 MOVE_8X,
                 MOVE_16X,
                 MOVE_32X,
                 MOVE_64X,
                 MOVE_128X,
                 MOVE_256X,
                 MOVE_SLEW);

{Move Directions}
  TMOVE_DIRECTION = (MOVE_FORWARD, MOVE_REVERSE);

{Command Status Values - Returned by the TCEC_GET_ACTIVITY_STATUS cmd}
  TTCES_PARK_STATUS = (PS_UNPARKED,
                       PS_PARKED,
                       PS_UNPARKING,
                       PS_PARKING,
                       PS_PARK_LOST,
                       PS_INITIALIZING);

  TTCES_MOVE_STATUS = (MS_BASE_RATE, MS_OTHER_RATE);

{Extended Error Codes - Returned by the TCEC_GET_EXTENDED_ERROR cmd}
  TTCE_EXTENDED_ERRORS = (TCEEE_NO_ERROR,
                          TCEEE_LIMIT_HIT,
                          TCEEE_USER_ABORT,
                          TCEEE_RA_TIMEOUT,
                          TCEEE_DEC_TIMEOUT,
                          TCEEE_COM_MOTION_TIMEOUT,
                          TCEEE_RA_COM_ERROR,
                          TCEE_DEC_COM_ERROR);

{Structs
 -------
 These struct type defines are used with the various commands. There are
 two types of structs, those ending with _DATA and those ending with _RESPONSE.

 The XX_DATA structs are used to feed data to the TCE for those commands
 that require data.

 The XX_RESPONSE structs are used to receive data back from the TCE in
 response to some command.

 Finally, the struct definitions start with TCE_ to avoid conflicts with
 any similarly names structs used with the Universal CPU and the center
 of the struct name echos the command the struct is associated with.
}

  TTCEGetEncodersResults = packed record
    rawRA        : longint;
    rawDEC       : longint;
    siderealRA   : longint;
    sideraalDEC  : longint;
    isSynced     : Word;
  end;

  TTCESyncEncodersParams = packed record
    siderealRA  : longint;
    siderealDEC : longint;
  end;

  TTCEGetExtendedErrorResults = packed record
    error   : Word;
  end;

  TTCEGetActivityStatusParams = packed record
    command   : Word;
  end;

  TTCEGetActivityStatusResults = packed record
    command  : Word;
    status   : Word;
  end;

  TTCEMoveParams = packed record
    raRate       : Word;
    decRate      : Word;
    raDirection  : Word;
    decDirection : Word;
  end;

  TTCEGotoParams = packed record
    deltaRA  : longint;
    deltaDEC : longint;
    rate     : Word;
  end;

  TTCEInitializeParams = packed record
    raRatio      : Word;
    decRatio     : Word;
    raDirection  : Word;
    decDirection : Word;
  end;

  TTCEEnableCommutationParams = packed record
    enable  : Word;
  end;

  TTCEActivateFocusParams = packed record
    tPlus   : Word;
    tMinus  : Word;
  end;

  TTCEEnablePECParams = packed record
    enable   : Word;
  end;

  TTCEOutputDewParams = packed record
    power  : Word;
  end;

  TTCETxToEXPParams = packed record
    dataPtr  : PChar;
    dataLen  : Word;
  end;

  TTCEEnableLimitParams = packed record
    enable  : Word;
  end;

  TTCESetEXPControlParams = packed record
    baud    : longint;
    control : Word;
  end;

  TTCEGetEXPStatusResults = packed record
    errs   : Word;
  end;

  TTCEGetResultBufParams = packed record
    command   : Word;
  end;

  TTCELimitStatusResults = packed record
    detected         : Word;
    inLimit          : Word;
    rawLimitRA       : longint;
    rawLimitDEC      : longint;
    siderealLimitRA  : longint;
    siderealLimitDEC : longint;
    limitTime        : longint;
  end;

  TTCEWriteBlockParams = packed record
    offset    : Word;
    segment   : Word;
    dataPrt   : PChar;
    dataLen   : Word;
  end;

  TTCEReadBlockParams = packed record
    offset   : Word;
    segment  : Word;
    length   : Word;
  end;

  TTCEGetROMVersionResults = packed record
    version   : Word;
  end;

  TTCESetCOMBaudParams = packed record
    baud   : longint;
  end;

  TTCESetMotionControlParams = packed record
    permanent        : Word;
    enableCOMTimeout : Word;
    raBase           : longint;
    decBase          : longint;
    acceleration     : longint;
    maxRate          : longint;
  end;

  TTCEGetMotionControlResults = packed record
    comTimeoutEnabled     : Word;
    raBase                : longint;
    decBase               : longint;
    acceleration          : longint;
    maxRate               : longint;
    raRatio               : Word;
    decRatio              : Word;
    raDirection           : Word;
    decDirection          : Word;
  end;

  TTCEReadThermistorResults = packed record
    thermistor   : Word;
  end;


  TTCEParkParams = packed record
    park  : Word;
  end;

  TTCEGetMotionStateResults = packed record
    raRate    : longint;
    decRate   : longint;
    deltaRA   : longint;
    deltaDEC  : longint;
  end;

  TTCEGetSiderealClockResults = packed record
    time  : longint;
  end;

  TTCESetSiderealClockParams = packed record
    time  : longint;
  end;

  TTCELoopbackEXPTestParams = packed record
    baud   : longint;
  end;

  TTCELoopbackEXPTestResults = packed record
    command   : Word;
    sent      : Word;
    errors    : Word;
  end;

  TTCEGetKeyResults = packed record
    keyStatus   : Word;
    keyHit      : Word;
  end;

  TTCEGetKeysResults = packed record
    number    : Word;
    keyStatus : Word;
    keysHit   : array[0..15] of Word;
  end;

  TTCEGetEEPROMDataResults = packed record
    serialNumber  : array[0..9] of char;
    data          : array[0..23] of char;
  end;

  TTCEGetTCEInfoResults = packed record
    version         : Word;
    cpu             : Word;
    firmwareVersion : Word;
    raROM           : Word;
    decRom          : Word;
    handPaddleRom   : Word;
    name            : array[0..31] of char;
  end;

  TTCESetEEPROMDataParams = packed record
    data  : array[0..23] of char;
  end;

{
 SBIG Use Only Structs.
 These are for use by SBIG in production testing of the TCE.
}

  TTCEWriteEEBlockParams = packed record
    address    : Word;
    dataPtr    : PChar;
    dataLen    : Word;
  end;

  TTCEReadEEBlockParams = packed record
    address  : Word;
    length   : Word;
  end;

  TTCEWriteR0Params = packed record
    value   : Word;
  end;

  TTCEReadR0Results = packed record
    value   : Word;
  end;

  TTCEGetEBSResults = packed record
    command   : integer;
    raEB      : Word;
    decEB     : Word;
  end;

  TTCEMicroOutParams = packed record
    motor   : Word;
    data    : array[0..14] of char;
  end;

  TTCEMicroOutResults = packed record
    command    : Word;
    result     : Word;
    data       : array[0..4] of char;
  end;

  TTCEWriteGAParams = packed record
    value   : Word;
  end;

  TTCEReadGAResults = packed record
    value   : Word;
  end;



(* Function Prototypes

   This is the driver interface function.  All camera commands are handled
   by the ParDrvCommand() routine and all TCE commands are handled by the
   TCEDrvCommand().

   Both functions take	a command parameter and pointers to parameters
   and results structs.

   The calling program needs to allocate the memory for the parameters
   and results structs and these routines read them and fill them in
   respectively.
*)

var
  RowBuffer              : Pointer;
  ContinueExposure       : Boolean;

  PAR_COMMAND            : TPAR_COMMAND;
  PAR_ERROR              : TPAR_ERROR;
  PAR_COMMAND_STATUS     : TPAR_COMMAND_STATUS;
  ABG_STATE7             : TABG_STATE7;
  DRIVER_REQUEST         : TDRIVER_REQUEST;
  CCD_REQUEST            : TCCD_REQUEST;
  CCD_INFO_REQUEST       : TCCD_INFO_REQUEST;
  IMAGING_ABG            : TIMAGING_ABG;
  PORT                   : TPORT;
  PORT_RATE              : TPORT_RATE;
  CAMERA_TYPE            : TCAMERA_TYPE;
  SHUTTER_COMMAND        : TSHUTTER_COMMAND;
  SHUTTER_STATE7         : TSHUTTER_STATE7;
  TEMPERATURE_REGULATION : TTEMPERATURE_REGULATION;
  LED_STATE              : TLED_STATE;
  FILTER_COMMAND         : TFILTER_COMMAND;
  FILTER_STATE           : TFILTER_STATE;
  AD_SIZE                : TAD_SIZE;
  FILTER_TYPE            : TFILTER_TYPE;
  AO_FOCUS_COMMAND       : TAO_FOCUS_COMMAND;

  TCE_COMMAND            : TTCE_COMMAND;
  MOVE_SPEED             : TMOVE_SPEED;
  MOVE_DIRECTION         : TMOVE_DIRECTION;
  TCES_PARK_STATUS       : TTCES_PARK_STATUS;
  TCES_MOVE_STATUS       : TTCES_MOVE_STATUS;
  TCE_EXTENDED_ERRORS    : TTCE_EXTENDED_ERRORS;

  StartExposureParams    : TStartExposureParams;
  EndExposureParams      : TEndExposureParams;
  ReadoutLineParams      : TReadoutLineParams;
  EndReadoutParams       : TEndReadoutParams;
  DumpLinesParams        : TDumpLinesParams;

  SetTemperatureRegulationParams : TSetTemperatureRegulationParams;
  QueryTemperatureStatusResults  : TQueryTemperatureStatusResults;

  ActivateRelayParams    : TActivateRelayParams;        

  PulseOutParams         : TPulseOutParams;
  TXSerialBytesParams    : TTXSerialBytesParams;
  TXSerialBytesResults   : TTXSerialBytesResults;
  GetSerialStatusResults : TGetSerialStatusResults;
  EstablishLinkParams    : TEstablishLinkParams;
  EstablishLinkResults   : TEstablishLinkResults;
  GetDriverInfoParams    : TGetDriverInfoParams;
  GetDriverInfoResults0  : TGetDriverInfoResults0;
  GetCCDInfoParams       : TGetCCDInfoParams;
  GetCCDInfoResults0     : TGetCCDInfoResults0;
  GetCCDInfoResults2     : TGetCCDInfoResults2;
  GetCCDInfoResults3     : TGetCCDInfoResults3;

  QueryCommandStatusParams   : TQueryCommandStatusParams;
  QueryCommandStatusResults  : TQueryCommandStatusResults;
  MiscellaneousControlParams : TMiscellaneousControlParams;
  ReadOffsetParams           : TReadOffsetParams;
  ReadOffsetResults          : TReadOffsetResults;
  AOTipTiltParams            : TAOTipTiltParams;
  AOSetFocusParams           : TAOSetFocusParams;
  AODelayParams              : TAODelayParams;

  SendBlockParams            : TSendBlockParams;
  SendByteParams             : TSendByteParams;
  ClockADParams              : TClockADParams;

  TCEGetEncodersResults      : TTCEGetEncodersResults;
  TCESyncEncodersParams      : TTCESyncEncodersParams;
  TCEGetExtendedErrorResults : TTCEGetExtendedErrorResults;
  TCEGetActivityStatusParams : TTCEGetActivityStatusParams;
  TCEGetActivityStatusResults: TTCEGetActivityStatusResults;

  TCEMoveParams              : TTCEMoveParams;
  TCEGotoParams              : TTCEGotoParams;
  TCEInitializeParams        : TTCEInitializeParams;
  TCEEnableCommutationParams : TTCEEnableCommutationParams;
  TCEActivateFocusParams     : TTCEActivateFocusParams;
  TCEEnablePECParams         : TTCEEnablePECParams;
  TCEOutputDewParams         : TTCEOutputDewParams;

  TCETxToEXPParams           : TTCETxToEXPParams;
  TCEEnableLimitParams       : TTCEEnableLimitParams;
  TCESetEXPControlParams     : TTCESetEXPControlParams;
  TCEGetEXPStatusResults     : TTCEGetEXPStatusResults;
  TCEGetResultBufParams      : TTCEGetResultBufParams;

  TCELimitStatusResults      : TTCELimitStatusResults;
  TCEWriteBlockParams        : TTCEWriteBlockParams;
  TCEReadBlockParams         : TTCEReadBlockParams;
  TCEGetROMVersionResults    : TTCEGetROMVersionResults;
  TCESetCOMBaudParams        : TTCESetCOMBaudParams;
  TCESetMotionControlParams  : TTCESetMotionControlParams;
  TCEGetMotionControlResults : TTCEGetMotionControlResults;

  TCEReadThermistorResults   : TTCEReadThermistorResults;
  TCEParkParams              : TTCEParkParams;
  TCEGetMotionStateResults   : TTCEGetMotionStateResults;
  TCEGetSiderealClockResults : TTCEGetSiderealClockResults;
  TCESetSiderealClockParams  : TTCESetSiderealClockParams;

  TCELoopbackEXPTestParams   : TTCELoopbackEXPTestParams;
  TCELoopbackEXPTestResults  : TTCELoopbackEXPTestResults;
  TCEGetKeyResults           : TTCEGetKeyResults;
  TCEGetKeysResults          : TTCEGetKeysResults;
  TCEGetEEPROMDataResults    : TTCEGetEEPROMDataResults;
  TCEGetTCEInfoResults       : TTCEGetTCEInfoResults;

  TCESetEEPROMDataParams     : TTCESetEEPROMDataParams;

  TCEWriteEEBlockParams      : TTCEWriteEEBlockParams;
  TCEReadEEBlockParams       : TTCEReadEEBlockParams;
  TCEWriteR0Params           : TTCEWriteR0Params;
  TCEReadR0Results           : TTCEReadR0Results;
  TCEGetEBSResults           : TTCEGetEBSResults;
  TCEMicroOutParams          : TTCEMicroOutParams;
  TCEMicroOutResults         : TTCEMicroOutResults;
  TCEWriteGAParams           : TTCEWriteGAParams;
  TCEReadGAResults           : TTCEReadGAResults;


function ParDrvCommand(Command : ShortInt;
                       Params  : Pointer;
                       Results : Pointer) : ShortInt; cdecl; far;
                       external 'SBIG32M.DLL' index 1;

implementation

end.


